-- Copyright 2010-2014 by Adin Hunter Baber, all rights reserved
local QuietMacrosName, QuietMacros = ...
-- built in api
-- blizzard api
local InCombatLockdown = InCombatLockdown
local strsplit = strsplit
local SetCVar = SetCVar
local DEFAULT_CHAT_FRAME = DEFAULT_CHAT_FRAME
local UIErrorsFrame = UIErrorsFrame
-- libs
-- local name space
-- locals
local Descriptions = {}
local CommandList = {}

QuietMacros.speechOff = false -- did QuietMacros turn off speech?
QuietMacros.soundEffectsOff = false -- did QuietMacros turn of sound effects?
QuietMacros.debugCommands = false
QuietMacros.debugVars = false


-- help text
Descriptions[#Descriptions+1] = "    /q help -- show list of QuietMacros commands"
function CommandList.help()
    DEFAULT_CHAT_FRAME:AddMessage("Quiet Macros commands")
    for k,v in  ipairs(Descriptions) do
        DEFAULT_CHAT_FRAME:AddMessage(v)
    end
end


-- turn off error speech
Descriptions[#Descriptions+1] = "    /q 0 -- turn off error speech"
CommandList["0"] = function()
    SetCVar("Sound_EnableErrorSpeech", 0)
    QuietMacros.speechOff = true
    QuietMacros.blockNextMessage = true
end


-- turn on error speech
-- clear error frame
Descriptions[#Descriptions+1] = "    /q 1 -- turn on error speech and clear error text"
CommandList["1"] = function()
    if QuietMacros.speechOff then
        SetCVar("Sound_EnableErrorSpeech", 1)
        QuietMacros.speechOff = false
    end
    if QuietMacros.soundEffectsOff then
        SetCVar("Sound_EnableSFX", 1)
        QuietMacros.soundEffectsOff = false
    end
    UIErrorsFrame:Clear()
end


-- sound effects off
Descriptions[#Descriptions+1] = "    /q seo -- turn off sound effects"
function CommandList.seo()
    SetCVar("Sound_EnableSFX", 0)
    QuietMacros.soundEffectsOff = true
end


-- clear error frame
Descriptions[#Descriptions+1] = "    /q c -- clear error text"
function CommandList.c()
    UIErrorsFrame:Clear()
end


-- no shift in combat
Descriptions[#Descriptions+1] = "    /q nsic -- no shifting in combat"
function CommandList.nsic()
    if InCombatLockdown() then
        SetCVar("AutoUnshift", 0)
    end
end


-- no shift at all
Descriptions[#Descriptions+1] = "    /q ns -- no shifting at all"
function CommandList.ns()
    SetCVar("AutoUnshift", 0)
end


-- allow shifting
Descriptions[#Descriptions+1] = "    /q as -- allow shifting"
function CommandList.as()
    SetCVar("AutoUnshift", 1)
end


-- debug on/off
Descriptions[#Descriptions+1] = "    /q debug command -- causes commands to be output to the chat box"
Descriptions[#Descriptions+1] = "    /q debug vars -- outputs variables"
Descriptions[#Descriptions+1] = "    /q debug off -- turns off debug text"
function CommandList.debug(arg)
    if arg == "command" then
        QuietMacros.debugCommands = true
        DEFAULT_CHAT_FRAME:AddMessage("QuietMacros debug Commands turned on")
    elseif arg == "vars" then
        QuietMacros.debugVars = true
        DEFAULT_CHAT_FRAME:AddMessage("QuietMacros debug vars turned on")
    elseif arg == "off" then
        QuietMacros.debugCommands = false
        QuietMacros.debugVars = false
        DEFAULT_CHAT_FRAME:AddMessage("QuietMacros debug turned off")
    end
end


SLASH_QUIETMACROS1 = "/q"
SLASH_QUIETMACROS2 = "/Q"
SlashCmdList["QUIETMACROS"] = function(commandMessage)
    commandMessage = commandMessage:lower()
    local command, arg1 = strsplit(" ", commandMessage)
    if CommandList[command] then
        if QuietMacros.debugCommands then
            DEFAULT_CHAT_FRAME:AddMessage("QuietMacros: "..(command or "Unkown"))
        end
        CommandList[command](arg1)
    end

    if QuietMacros.debugVars then
        DEFAULT_CHAT_FRAME:AddMessage("Sound_EnableErrorSpeech: "..GetCVar("Sound_EnableErrorSpeech"))
        DEFAULT_CHAT_FRAME:AddMessage("Sound_EnableSFX: "..GetCVar("Sound_EnableSFX"))
        DEFAULT_CHAT_FRAME:AddMessage("AutoUnshift: "..GetCVar("AutoUnshift"))
        DEFAULT_CHAT_FRAME:AddMessage("Error speech turned off by QuietMacros: "..(QuietMacros.speechOff and "true" or "false"))
        DEFAULT_CHAT_FRAME:AddMessage("Sound Effects turned off by QuietMacros: "..(QuietMacros.soundEffectsOff and "true" or "false"))
    end;
end;
